changeset 1036:959139283fc7

*** empty log message ***
author Jim Meyering <jim@meyering.net>
date Sat, 20 Sep 1997 19:33:05 +0000
parents 9496653f8515
children b24d08ec1fa3
files lib/hash.c
diffstat 1 files changed, 9 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/lib/hash.c
+++ b/lib/hash.c
@@ -169,17 +169,17 @@
   return ht->hash_table_size;
 }
 
-/* CANDIDATE_TABLE_SIZE need not be prime.  If WHEN_TO_REHASH is positive, when
-   that percentage of table entries have been used, the table is
-   deemed too small;  then a new, larger table (GROW_FACTOR times
-   larger than the previous size) is allocated and all entries in
-   the old table are rehashed into the new, larger one.  The old
-   table is freed.  If WHEN_TO_REHASH is zero or negative, the
-   table is never resized.
+/* CANDIDATE_TABLE_SIZE need not be prime.  If WHEN_TO_REHASH (FIXME: add
+   this parameter) is positive, when that percentage of table entries have
+   been used, the table size is increased;  then a new, larger table
+   (GROW_FACTOR (FIXME: maybe add this parameter) times larger than the previous
+   size) is allocated and all entries in the old table are rehashed into
+   the new, larger one.  The old table is freed.  If WHEN_TO_REHASH is zero
+   or negative, the table is never resized.
 
    The function returns non-zero
-   - if TABLE_SIZE is zero or negative
-   - if EQUALITY_TESTER or HASH is null
+   - if CANDIDATE_TABLE_SIZE is zero or negative
+   - if KEY_COMPARATOR or HASH is null
    - if it was unable to allocate sufficient storage for the hash table
    - if WHEN_TO_REHASH is zero or negative
    Otherwise it returns zero.